@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef _LIBCUDACXX___ALGORITHM_COUNT_H
-#define _LIBCUDACXX___ALGORITHM_COUNT_H
+#ifndef _CUDA_STD___ALGORITHM_COUNT_H
+#define _CUDA_STD___ALGORITHM_COUNT_H
 
 #include <cuda/std/detail/__config>
 
@@ -24,7 +24,7 @@
 
 #include <cuda/std/__cccl/prologue.h>
 
-_LIBCUDACXX_BEGIN_NAMESPACE_STD
+_CCCL_BEGIN_NAMESPACE_CUDA_STD
 
 _CCCL_EXEC_CHECK_DISABLE
 template <class _InputIterator, class _Tp>
@@ -42,8 +42,8 @@ count(_InputIterator __first, _InputIterator __last, const _Tp& __value_)
   return __r;
 }
 
-_LIBCUDACXX_END_NAMESPACE_STD
+_CCCL_END_NAMESPACE_CUDA_STD
 
 #include <cuda/std/__cccl/epilogue.h>
 
-#endif // _LIBCUDACXX___ALGORITHM_COUNT_H
+#endif // _CUDA_STD___ALGORITHM_COUNT_H
